--- 

title: "Coronavirus and the planetary environmental crisis"
images: ["/images/care_curve.jpg"]
---

# Environmental roots of the pandemic

According to Epidemiologist Dennis Carroll, the ongoing research from EcoHealth Alliance, an organisation protecting wildlife and public health from the emergence of disease,[^0] shows that the last four decades have seen a two- to three-fold increase in zoonotic leaps of viruses from animals to humans.[^1] The increased incidence of epidemics such as Coronavirus is a consequence of, on the one hand, the rapid expansion of industrial agriculture and industrial farming into wildlife habitats and, on the other hand, the growing inclusion of wild species into capitalist commodity chains.[^2] It is the interface zones between the receding wildlife territories and encroaching farming that facilitate zoonotic leaps from wild animals to farm animals, with a particular contribution of the fruit bats.[^3] From there they spread to human populations. The leaps from industrially farmed animals such as pigs, fowl and dromedary camels to humans have been at the root of avian flu, swine flu, SARS, MERS, H5N2 and H5Nx flue epidemics. 

Degraded ecosystems, with their complexity reduced to benefit industrial farming and monocrops, have a lowered inherent capacity to halt the spread of epidemics among the wild species. Therefore planetary ecological destabilisation, a combination of climate change, land-use change and biochemical rifts, is expected to spawn new pathogens at an increasing rate. In fact, one of the indicators of destabilisation of planetary boundaries proposed by the Stockholm Resilience Institute are novel entities, which include human-made non-living materials and living beings such as synthetic pollutants radioactive materials, nanomaterials, micro-plastics or genetically modified organisms, and can also be understood to include the mutagenic viruses that emerge from conditions created by the actions of industrial agriculture.

# Environmental consequences of the pandemic

In the early days of lockdown in Hubei satellite images released by NASA were making rounds suggesting that the cessation of industrial production and reduction of traffic has radically reduced both the air pollution and as a consequence might save as many 77.000 lives.[^4] Large North Italian cities such as Milan, notorious for their air pollution levels, have experienced a radical reduction in pollution as well.[^5] In a seeming display of entirely irrational behaviour, as travellers started to abort their travel plans, the air carriers were let to resume their flights with almost no passengers on board. The pollution from now grounded fleets of commercial aeroplanes is the cause of 16.000 preventable deaths worldwide on an annual basis.[^6] And the irony of the matter is that lowered air pollution is beneficial to recovery from Corona. The slowdown in economic activity during the outbreak is bound to have a major impact on lowering global greenhouse gasses emissions as well.

However, the reduction in pollution and emissions coming from the breakdown rather than from a politically-driven and participatory transition is not something we should cheer. Weighing relative numbers of dead bodies is a dismal Malthusianism in disguise.[^7] As the world leaps back from the crisis, the vulnerable communities will be left to suffer, while the environmentally impactful patterns of the capitalist system of production will come back with full force. In fact, Saudis and Russians are waging a price-war by pushing more cheap oil onto the world market far above what is currently needed in conditions of reduced demand. Once the outbreak slows down, the world might be awash with cheap oil, which might open an avenue to quickly undo the emissions reduction that we saw during the outbreak. To cut a long story short, creating a sustainable and just life for all calls for politics and not breakdown.

# Environmental lessons from the pandemic

Still, while we are in the midst of the crisis, there is an opening to reconsider how our systems of production and consumption are organised and what are their purposes. Radical demands for coordinated management of social adaptation, massive effort to save human lives, collective willingness to change the organisation of our lives, radical redistribution and willingness to accept the uncertainty in the face of tragedy surprisingly seem possible. TINA-doctrine seems suddenly if for a moment, reduced to a ridiculous historic fetish of a group of sociopaths who have benefited from the complacency of an extended peace-time period and growing affluence to willfully indulge with their class into a social experiment of throwing people's lives under the wheels of restoring profits.

From the current pandemic we have learned many valuable lessons for the ecological transition:
- lives in the long-run take precedence over the economy in the short-run
- responses to massive threats to human lives can only be socially planned and managed
- a lack of global cooperation can exacerbate the threat (but will boomerang as Trump's administration or the EU are now finding out)
- an important pillar of managing threat is taking back control over privatised social services and infrastructure
- companies can be pushed to submit to government-imposed management if their business model is made no longer viable and be commandeered to produce for social needs
- fiscal policies are an essential instrument of directing social adaptation
- commodified provision of housing, food and health can be socialised;
- in critical moments the work of social reproduction, otherwise backgrounded, made invisible and considered economically secondary to production replaceable things, emerges as essential and most valuable to societies
- people are willing to contribute en masse to that work of social reproduction
- patterns of daily life can radically change overnight facing a massive threat and be embraced by the people
- what becomes critical for a radical change is how to organise the freed human capacity for socially meaningful work and convivial free time 

There are evident parallels between the global ecological destabilisation and the Coronavirus pandemic. Both are seemingly invisible process, more claims by scientists than a lived reality until they become painfully felt in the loss of human lives and the collapse of ways of life that seemed unchangeable hitherto. Yet global environmental destabilisation is distributed highly unevenly in terms of geography and temporal scales. The affluent will at first mostly be able to limit their exposure, whilst the poor in the sacrificial zones of the southern hemisphere are already left to suffer. But in due time, no one will escape the runaway destabilisation of the planetary ecosystems. Timescales of action are not measured in weeks but in years and decades. 

With the about-turn in the socio-economic doctrine and the sense of what is possible, we can see this as a historic opening to re-set the terms of the political debate over a long-term threat and to organise collective action to push for a just and sustainable future that will save lives and ecosystems. What is happening now is a drastic departure from the political status quo, showing that human lives come before capitalist accumulation. If people can understand the crisis precipitated in a sudden spike of viral spread, now more than ever we should be able to visualise the crisis precipitated by the slow and even more deadly ecological destabilisation. A radical, socially managed transformation has been shown to be possible. It has to be, however, made urgent. And it has to start from the conditions of socio-economic trouble that the pandemic will leave in its wake.


# Further reading
**For texts referenced in this session see the Notes section below.**

- [Robert G. Wallace, Rodrick Wallace (eds.): "Neoliberal Ebola: Modeling Disease Emergence from Finance to Forest and Farm"](http://93.174.95.29/_ads/8D07B63757F066F0203EE0F4A68B18DD)
- [Robert G. Wallace: "Big Farms Make a Big Flu"](https://aaaaarg.fail/thing/5d5484679ff37c2d4c622bf8)
- [What would happen if the world reacted to climate change like it’s reacting to the coronavirus?](https://www.fastcompany.com/90473758/what-would-happen-if-the-world-reacted-to-climate-change-like-its-reacting-to-the-coronavirus?fbclid=IwAR3GF--L8EW5IqGFCH4p6RQqZ2ylLGKw7x7iAPXwg1kbMuu5mp6_LUk2Z1o)
- [Can Capitalist Reform Save The Environment?](http://www.leftcom.org/en/articles/2020-02-24/can-capitalist-reform-save-the-environment?fbclid=IwAR0RiK8pOb46Ea0bHIKTZki-JxOjhNjahEiJivUnqxHMTVXOcMGPs_BS7Lc)

.
.
.

# Notes

[^0]: [EcoHealth Alliance's Publication](https://www.ecohealthalliance.org/publications)

[^1]: ["The Man Who Saw the Pandemic Coming"](http://nautil.us/issue/83/intelligence/the-man-who-saw-the-pandemic-coming)

[^2]: [Robert G. Wallace: "Coronavirus: »Agribusiness would risk millions of deaths.«"](https://www.marx21.de/coronavirus-agribusiness-would-risk-millions-of-deaths/), [Robert G. Wallace: "Big Farms Make a Big Flu"](https://aaaaarg.fail/thing/5d5484679ff37c2d4c622bf8)

[^3]: [Jim Robbins: "The Ecology of Disease"](https://www.nytimes.com/2012/07/15/sunday-review/the-ecology-of-disease.html), 

[^4]: ["Study: Coronavirus Lockdown Likely Saved 77,000 Lives In China Just By Reducing Pollution"](https://www.forbes.com/sites/jeffmcmahon/2020/03/16/coronavirus-lockdown-may-have-saved-77000-lives-in-china-just-from-pollution-reduction/)

[^5]: ["Coronavirus Causes Decline in Air Pollution Across Northern Italy"](https://www.greenmatters.com/p/italy-air-pollution-coronavirus)

[^6]: ["Aircraft emissions ‘responsible for 16,000 deaths per year’""](https://airqualitynews.com/2015/07/27/aircraft-emissions-responsible-for-16000-deaths-per-year/)

[^7]: [Eric Holthaus: "No, the coronavirus is not good for the climate"](https://thecorrespondent.com/330/no-the-coronavirus-is-not-good-for-the-climate/43687590870-ae5ff40e)







