---
title: "Tech and Science in the time of COVID-19"
images: ["/images/care_curve.jpg"]

---

The politics of technology at a time like this can become much more apparent than when our digital infrastructures runs smoothly. Massive transition to digital communication, platform infrastrcutures and automated processes as we avoid meeting live, doing shopping and direct human contact are bound to have long-term knock-on effects on technological ecosystem and yet larger effects on labour. The perennial technopolitical concerns over lock-ins, net neutrality, dataveillance, ownership over data, public ownership over communication infrastructure and the entrenched power of technological oligopolies are staring at us back. 

This session, unlike others presented here, does not contain tips for moving into action (unless, perhaps, if you are an engineer), but it offers an archive of relevant news that can help to start common debates and reflections on what demands we should collectively place for a more just technopolitical future. 

# Connectivity 
During this crisis, online video conferencing has come to the fore. Many management strategies for COVID-19 involve increased use of VPNs and online video chats that rely on digital infrastructure. A growing number of colleges are moving classes to online platforms. Yet few of us pay attention to extra burden than the increased data traffic is placing on the capacity of the net and the individual providers and how this will impact differently those with slower or more limited access. Also, more essential online services, for example conference calls between healthcare practitioners and patients, find themselves competing with less essential apps and games. In China, for instance, several [crashes](https://www.abacusnews.com/culture/worlds-biggest-online-population-staying-home-and-chinas-internet-cant-cope/article/3050947) have been reported.

Public health and safety are the top priorities in managing the COVID-19 outbreak. Data centers play a key behind-the-scenes role, providing mission-critical technology to support emergency communication for public agencies, emergency services and 911 systems. Major hospitals also rely upon data centers for data and images storage and transmission. Few are aware that data centres too are under pressure to continue to provide seamless services while also protecting their staff. SOURCE: [Data Centers Prepare Contingencies for Coronavirus Spread](https://datacenterfrontier.com/silicon-valley-data-centers-prepare-contingencies-for-coronavirus-spread/)

The role of connectivity is something that merits some collective reflection. One point of departure comes from Ian Alan Paul, 

> It appears that at least two new kinds of subjectivity have already begun to take shape, both of which are mutually constitutive, intimately dependent upon, and shaped by the informatic infrastructures and apparatuses that now run through and organize much of our planetary society. On the one hand, we have the domesticated/connected subject, who in being confined to their home is pushed to invent new ways to reconnect to and participate in a virtualized economy. On the other hand, we have the mobile/disposable subject that serves as the circulatory system of the pandemic, a subject that becomes increasingly vulnerable and precarious as it is compelled to move at ever greater velocities. In order for domesticated/connected subjects to materially sustain themselves, they must be coupled with the mobile/disposable subject that fulfills the minimum material needs of society while ensuring the social possibility of isolated yet networked domestic life.

**Source:**
- [The Corona Reboot](https://www.ianalanpaul.com/the-corona-reboot/)

# Robots, AI and the automation of healthcare 
While the corporate sector emphasizes the benefits of digital tools for healthcare, they are usually less keen to speak about issues such as the politics of surveillance and data collection; the private ownership of key software and tools which hospitals might end up relying upon; the loss of jobs in the care sector and the repercussions on the quality of care that automated, remote services might generate.

IN CHINA:
Chinese technology giants are accelerating their efforts in the field of health-care technology in areas from cloud computing to artificial intelligence (AI) amid the new coronavirus outbreak. Giant companies such as Alibaba, Baidu, Tencent, Huawei and DiDi have all launched new health tech features aimed at diagnosing cases and finding a vaccine for the coronavirus. 

**Source:**
- [China’s giants from Alibaba to Tencent ramp up health tech efforts to battle coronavirus](https://www.cnbc.com/2020/03/04/coronavirus-china-alibaba-tencent-baidu-boost-health-tech-efforts.html)

Hospitals in China have turned to a trio of robots to help halt the spread of the flu-type virus. The robots include a food delivery robot, sanitizing robot, and directional guiding robot that can help people avoid unnecessary human contact. They are currently being utilized across 10 provinces in Chinese hospitals.

**Source:**
- [In China’s hospitals, robots are helping to halt the spread of coronavirus]()
https://www.digitaltrends.com/cool-tech/trio-of-robots-china-hospitals/)

China has become the world’s largest market for industrial robotics and the fastest-growing market worldwide, surging 21% to $5.4 billion in 2019, while global sales hit $16.5 billion, according to the International Federation of Robotics in Frankfurt. China counts more than 800 robot makers, including major players SIASUN and DJI Innovations. China is on track to account for 45% of all industrial robot shipments by 2021, up from 39% in 2019. One robot that can work a 24-hour shift can replace three workers and cost in the range of $43,000 to $72,000. With salaries in China going up as much as 20% annually in recent years, China business consultant Bill Edwards foresees an inevitable push to robotics. “Wages in China are no longer cheap,” he observed.

**Source:**
- [The rush to deploy robots in China amid the coronavirus outbreak](https://www.cnbc.com/2020/03/02/the-rush-to-deploy-robots-in-china-amid-the-coronavirus-outbreak.html)

# Open Access 
Open access to scientific knowledge remains one of the central demands for healthcare justice. Laboratories around the world have been able to share genome sequences of the newly emerging coronavirus (hCoV-19) through [GISAID](https://www.gisaid.org), an initiative that promotes the international sharing of all influenza virus sequences to help researchers understand how the viruses evolve, spread and potentially become pandemics. GISAID does so by overcoming disincentives/hurdles or restrictions, which discourage or prevented sharing of influenza data prior to formal publication. The Initiative ensures that open access to data in GISAID is provided free-of-charge and to everyone. However, the GISAID is an exception to the way medical/scientific research and data are kept as privatized assets to be capitalized upon. In 2015, Liberian public health officials co-authored a New York Times op-ed that lamented the amount of critical Ebola research that was unknown or inaccessible to scientists and health workers at the center of the 2014 epidemic. 

To bypass existing paywalls, in January 2020 a group of online archivists have created an open-access directory of over 5,000 scientific studies about coronaviruses that anyone can browse and download. The download was made possible via [Sci-Hub](https://www.sci-hub.tw/), a free scientific research repository sometimes called “the Pirate Bay of science.” Sci-Hub's site says it provides free access to over 78 million research articles by downloading HTML and PDF pages off the web, in some cases bypassing paywalls. Because of this, major scientific publishing companies—most prominently Elsevier—have repeatedly sued Sci-Hub for copyright infringement.

**Source:**
- ['It’s a Moral Imperative:' Archivists Made a Directory of 5,000 Coronavirus Studies to Bypass Paywalls](https://www.vice.com/en_us/article/z3b3v5/archivists-are-bypassing-paywalls-to-share-studies-about-coronaviruses?fbclid=IwAR1X44-D2C9mFHFx2N4HyEz0Kon1NnN93PAjhD1NM52AN7eHl3NFqJjj3cw) 

# The responses of the maker scene
Amid the global shortage of medical supplies and equipments, various makerspaces and fablabs have been discussing and mobilising around certain areas of intervention, calling attention once again to the political tension between autonomous technologies and the necessity of regulations and standards. This is a tension that is not resolved with quick deliberation, but one that merits a large collective reflection moving forward. 

A key example from Italy took place at the Chiari Hospital (Brescia), which had to face an emergency within the emergency, when the medical staff realized that the supply of valves necessary for the functioning of a resuscitation tool was running out and that the manufacturer had run out of spare parts due to the high demand. A local 3D printing company, involved by a Milanese fablab, was contacted and they were able to produce a copy of the valve in less than 6 hours. However, the manufacturer is now menacing to sue and technically producing this piece of equipment could also incur in legal troubles as it has not been certified as safe by the health authorities. The Italian Republic, like many others, could stop or prevent an eventual lawsuit via a legislative act of 2005 (LD 10 February 2005, n. 30, Art. 141) regulating state expropriations of registered or patented industrial property rights if this is "in the interest of the country's military defense or for other reasons of public utility."
(via @zoescope).

**Sources:**
- [Italian hospital saves Covid-19 patients lives by 3D printing valves for reanimation devices](https://www.3dprintingmedia.network/covid-19-3d-printed-valve-for-reanimation-device/#comment-7095)
- [(ITA) Coronavirus, a Brescia manca una valvola per i rianimatori: ingegneri e fisici la stampano in 3D in sei ore](https://it.businessinsider.com/coronavirus-manca-la-valvola-per-uno-strumento-di-rianimazione-e-noi-la-stampiamo-in-3d-accade-nellospedale-di-chiari-brescia/)
- [Discussion thread on the fb group 'Fabber in Italia' initiated by Zoe Romano]( https://www.facebook.com/search/top/?q=fabber%20in%20italia&epa=SEARCH_BOX)


# The problem with working online 

As many tasks and meetings are moved online, including, crucially, teaching activities, we urgently need a workers-led reflection on the use and owneership of online platforms. These tools risk to prepare the terrain for a restructuring of working conditions that might justify further layoffs and increase worker's surveillance. Importantly, issues of ownership of these technological infrastructure (owned by companies that are making profit via the licences and the reselling of the data collected); questions of privacy and opt-out options for users; and of control over the generated contents (let's think for example, at lectures being recorded which can then be used to replace teachers) feature strongly here. If you are part of a union or if your workplace is introducing tools for remote workflows, consider raising some of the issues and launching an equiry into what tool are deployed and how. 


# Other resources from Pirate Care
- [John Wilbanks (Sage Bionetworks/ FasterCures): Open Science, DIY Bio, and Cheap Data. Video from the Pirate Care Conference, Coventry University, June 2019]
- [Rebelling with Care. Exploring open technologies for commoning healthcare.](https://hcommons.org/deposits/item/hc:26681/) 
- [Also available in ITA](http://wemake.cc/digitalsocial/cure-ribelli/)
- [Nick Titus from the Four Thieves Vinegar Collective. Video from the Pirate Care Conference, Coventry University, June 2019](https://www.youtube.com/watch?v=VgMPGOw3Flg&list=PLX-N8krB2JMcVktrreeqLJAKTYqNoiSnO&index=18)


# Further reading
- [Solidarity infrastructure for solidarity actions](https://www.systemli.org/en/2020/03/15/solidarity-as-infrastructure.html)
- [Coronavirus Tech Handbook](https://coronavirustechhandbook.com/) - A crowdsourced resource for technologists building things related to the coronavirus outbreak.
- [Open source medical supplies FB group](https://www.facebook.com/groups/670932227050506/)
- [Ultimate Medical Hackathon: How Fast Can We Design And Deploy An Open Source Ventilator?, by Hackaday](https://hackaday.com/2020/03/12/ultimate-medical-hackathon-how-fast-can-we-design-and-deploy-an-open-source-ventilator/?fbclid=IwAR3maVAuLJrnh0LQaCqst2Kd7baXTECdjIp2gwKvAy7hERbtfGADpqtX1kw)
- [How profit makes the fight for a coronavirus vaccine harder](https://www.theguardian.com/commentisfree/2020/mar/04/market-coronavirus-vaccine-us-health-virus-pharmaceutical-business?fbclid=IwAR0939HhgT82I5_xYvdtDHfnMQM085qN0dodE4nmZ0UP3ZNQQW_btbpoWCY)
- [Impacts of operational failures on primary care physicians’ work: A critical interpretive synthesis of the literature](https://www.thisinstitute.cam.ac.uk/research-articles/impacts-operational-failures-primary-care-physicians-work-critical-interpretive-synthesis-literature/?fbclid=IwAR0RECSGxF8WKywluZ96Ij1FF0goZaKl3cy3jKKeyQy5jp7B-69Sw7q9oYE)
- [Trump 'offers large sums' for exclusive US access to coronavirus vaccine](https://www.theguardian.com/us-news/2020/mar/15/trump-offers-large-sums-for-exclusive-access-to-coronavirus-vaccine?fbclid=IwAR1EMkygoVegxNW_t6gQG5gGFBhwqGWjfZzUZGu8foRrhgGZBSeUAasulTs)
- [The science of soap – here’s how it kills the coronavirus](https://www.theguardian.com/commentisfree/2020/mar/12/science-soap-kills-coronavirus-alcohol-based-disinfectants?fbclid=IwAR3me0dXBmL2kxFv5m8lXN3JXnk-WUs5xDpxyOmYX7VTTIX2-_7UF0Rgm90)

