---
title: Situating Care
---


# What is care, where is it and what can it do?

The term care can refer to a broad variety of activities and hold different meanings for different people. And yet, all depend on its provision to some extent, all practice it , albeith in widely different conditions, and all experience its effects, in negative and positive ways. Below you will find an activity that can help situating one’s experience of care; followed by some key definitions of care and a list of resources to unpack its various meanings and implications, organised in four groups: Care Ethics, Care of the Self, Caring as a Way of Knowing, Care Labour and Social Reproduction. 


## Introduction exercise: Care in your languages?

This exercise can be practice also by those whose only language is English. 
Other languages have more than one word to express the meaning of care. If you are in a group where people speak different languages (or yourself do), it can be generative to list how care and similar concepts are expressed in these languages, how and when are these used, and what aspects of care they capture. Try to think of different context for when these words might be used and by whom, and what impressions or images are associated with them.

If for you or your group the only language is English, you can skip this first passage and move to the second moment of this reflection.

The second step in this introductory exercise would consist of finding synonyms of the world ‘care’ or ‘caring’. Can you group them in different categories? Are there particular places of people associated with them? 

Finally, generate a list of activities that you associate with ‘care labour’. Do these activities share some characteristics? What kinds of skills are necessary for each? And what kind of resources and tools? Can you group the different kind of work together in different sub-groups? What might be different criteria for doing so? Are particular places or persons excluded from this listed activities? 

This exercise can be used as entry points to initiate a collective reflection on care for a group who might want to revisit its own way of perceiving, distributing and valuing its labour. The literature on care is vast, and it is therefore important to ask oneself what do we need to learn in the process of engaging with it? What needs change?  

**
Some definitions of care and social reproduction:**

- Joan Tronto and Berenice Fisher. "Toward a feminist theory of caring." Circles of care: Work and identity in women’s lives (1990), 35-62:

> In the most general sense, care is a species activity that includes everything we do to maintain, continue and repair our world so that we may live in it as well as possible. That world includes our bodies, ourselves and our environment, all of which we seek to interweave in a complex, life-sustaining web. 

- Yeates, Nicola. 2004. “Global Care Chains. Critical Reflections and Lines of Enquiry” International Feminist Journal of Politics, 6 (3): 369–91:
> a range of activities and relationships that promote the physical and emotional well-being of people “who cannot or who are not inclined to perform these activities themselves 

- Camille Barbagallo, [The Impossibility of the International Women’s Strike is Exactly Why It’s So Necessary]( https://novaramedia.com/2017/03/06/the-impossibility-of-the-international-womens-strike-is-exactly-why-its-so-necessary/), Novara Media, 6th March 2017:
> All the work we (mostly women) do that makes and remakes people on a daily basis and intergenerationally.

- David Graeber (twitter):
> Caring labour is aimed at maintaining or augmenting another person’s freedom.

-  Nacy Fraser. ["Contradictions of capital and care."](https://newleftreview.org/issues/II100/articles/nancy-fraser-contradictions-of-capital-and-care) New Left Review 100.99 (2016), 117:


> interactions that produce and maintain social bonds.

- María Puig de la Bellacasa "‘Nothing comes without its world’: Thinking with Care." The Sociological Review 60.2 (2012), 197-216:

> To care about something, or for somebody, is inevitably to create relation. Caring is more than an affective-ethical state: it involves material engagement in labours to sustain interdependent worlds, labours that are often associated with exploitation and domination.


## Grounding exercise: Organisational Mapping of Care 

(Alone or as a group)

The purpose of this activity is to become more away of the complex and intertwined webs of care that support or shape our lives, and to the different kinds of conditions and skills that characterise care labour. 

Map a typical day in your everyday life across the different organizations/institutions within which your various activities take place. (For example, your home, public transport, school, shop, gym, etc…). There is no one way to map your organisational life. It can be as detailed or as broad as it feels useful to you. Some people prefer more abstract diagrams, some use concentric circles or  arrows, others chose more intricate ways of drawing and representing the various organizations.

As a second step, add into the map (some or all) the main people with whom you interact in the different organisations. 

Now consider the following definition of care offered by Evelyn Nakano Glenn (author of [Forced to Care: Coercion and Caregiving in America](https://library.memoryoftheworld.org/#/book/ab05564f-e1b0-4172-94ac-39efe920768f), Harvard University Press, 2010):


> Caring can be defined most simply as the relationships and activities involved in maintaining people on a daily basis and intergenerationally. Caring labor involves three types of intertwined activities. First, there is direct caring for the person, which includes physical care (e.g., feeding, bathing, grooming), emotional care (e.g., listening, talking, offering reassurance), and services to help people meet their physical and emotional needs (e.g., shopping for food, driving to appointments, going on outings). The second type of caring labor is that of maintaining the immediate physical surroundings/milieu in which people live (e.g., changing bed linen, washing clothing, and vacuuming floors). The third is the work of fostering people's relationships and social connections, a form of caring labor that has been referred to as "kin work" or as "community mothering." An apt metaphor for this type of care labor is "weaving and reweaving the social fabric." All three types of caring labor are included to varying degrees in the job definitions of such occupations as nurses' aides, home care aides, and housekeepers or nannies. Each of these positions involves varying mixtures of the three elements of care, and, when done well, the work entails considerable (if unrecognized) physical, social, and emotional skills.


Keeping the three types of care labour described by Evelyn Nakano Glenn, chose a way of representing them and ascribe them to the people in the map in relation to you (giving/receiving care).


**Reflection Questions:**

* Is care spread evenly across your organisational map?

* What are the organisations where you identified more care activities? Do they have similarities between them? (for instance, the way they are organised, their social purpose, their size, the kind of space they occupy?)

* What are the people from who you receive most care? The ones to whom you give most? Do these people have similarities with you (age, class, race, gender, education levels, etc.)? Do these people have similarities between themselves? 

* Are your interactions more involved in one kind of care activities than others? Can you think of the reasons for why this is the case? 

* Are people from whom you receive care always the same as those who also are recipient of your care actions? 

* Let's now consider the three different kinds of care activities? Which ones are takin gplace as part of a paid job or service? Which ones are unpaid? Which ones are visible and valued socially? Which ones are not? 

* Are there people in your map with whom you don't have any care interaction? What is their position in relation to you? 

Different ways of thinking about care:



# Care Ethics


“The moral theory known as “ the ethics of care” implies that there is moral significance in the fundamental elements of relationships and dependencies in human life. Normatively, care ethics seeks to maintain relationships by contextualizing and promoting the well-being of care-givers and care-receivers in a network of social relations. Most often defined as a practice or virtue rather than a theory as such, “care” involves maintaining the world of, and meeting the needs of, ourself and others.”

- [Care Ethics.](https://www.iep.utm.edu/care-eth/#H2) Internet Encyclopedia of Philosophy


## Some key readings

- ![](bib:e092d7cf-fe2c-4487-9963-98fd3fc7523b)

- Nel Noddings, [Caring: A Relational Approach to Ethics & Moral Education](https://library.memoryoftheworld.org/#/book/8acc45a2-ea36-4e3f-a86f-e168692166e8), University of California Press, 2013 [1984]. 

- ![](bib:fe352bc2-c2b3-4efe-9837-cc988d1f1c22)

- ![](bib:dd5a0b7c-7754-47be-87fd-1f015fd28514)

- ![](bib:44abb3ff-8e49-40f6-b476-709c1f9c34fc)


## Further Resources

- [Website of the Foundation Critical Ethics of Care](https://ethicsofcare.org/care-ethics/)


- [The International Care Ethics Research Consortium (CERC)](https://care857567951.wordpress.com/) 


- Ranjoo Seodu Herr. “Is Confucianism Compatible with care ethics?: A Critique.” Philosophy East and West 53.4, 2003, 471-489.

- Mijke van der Drift. “Nonnormative Ethics: the Ensouled Formation of Trans.” In: The Emergence of Trans. Cultures, Politics and Everyday Lives. Edited ByRuth Pearce, Igi Moon, Kat Gupta, Deborah Lynn Steinberg. 
London: Routledge. 2019.

- Sandra Harding. “The Curious Coincidence of Feminine and African moralities: Challenges for Feminist Theory” in Women and Moral Theory, eds. Eva Feder Kittay and Diana T. Meyers. Totowa, NJ: Rowman and Littlefield, 1987.



# Care of the Self

## Introductory reading

- André Spicer. [“‘Self-care’: how a radical feminist idea was stripped of politics for the mass market.”](https://www.theguardian.com/commentisfree/2019/aug/21/self-care-radical-feminist-idea-mass-market) The Guardian, 21 August 2019.

## Some key readings

- Audre Lorde. [A Burst of Light: and other essays.](https://library.memoryoftheworld.org/#/book/4795e144-32a3-4ee4-afd0-500199b1da41) Mineola, New York: Ixia Press, an imprint of Dover Publications, 2017.

> Winner of the 1988 Before Columbus Foundation National Book Award, this path-breaking collection of essays is a clarion call to build communities that nurture our spirit. Lorde announces the need for a radical politics of intersectionality while struggling to maintain her own faith as she wages a battle against liver cancer. From reflections on her struggle with the disease to thoughts on lesbian sexuality and African-American identity in a straight white man's world, Lorde's voice remains enduringly relevant in today's political landscape. Those who practice and encourage social justice activism frequently quote her exhortation, "Caring for myself is not self-indulgence, it is self-preservation, and that is an act of political warfare." 

- Michel Foucault. [The Care of the Self. Volume 3 of the History of Sexuality.](https://library.memoryoftheworld.org/#/book/e99416e9-9c62-44d7-b5d9-dab8ee67c187) New York: Pantheon Books, 1986.


- Michel Foucault.  [“The Ethics of the Concern of the Self as a Practice of Freedom”](https://library.memoryoftheworld.org/#/book/7f69b216-4ae6-4b2b-aba7-8d31fb477516), in Ethics: Subjectivity and Truth. New York: The New Press, 1997. 281-301. 

> The risk of dominating others and exercising a tyrannical power over them arises precisely only when one has not taken care of the self and has become the slave of one’s desires. But if you take proper care of yourself, that is, if you know ontologically what you are, if you know what you are capable of, if you know what it means for you to be a citizen of a city... if you know what things you should and should not fear, if you know what you can reasonably hope for and, on the other hand, what things should not matter to you, if you know, finally, that you should not be afraid of death – if you know all this, you cannot abuse your power over others.  

- Michel Foucault.  [“Technologies of the Self” in Ethics: Subjectivity and Truth.](https://library.memoryoftheworld.org/#/book/7f69b216-4ae6-4b2b-aba7-8d31fb477516) New York: The New Press, 1994. 221-251. 

> There are several reasons why “know yourself” has obscured “take care of yourself.” First, there has been a profound transformation in the moral principles of Western society. We find it difficult to base rigorous morality and austere principles on the precept that we should give more care to ourselves than to anything else in the world. We are more inclined to see taking care of ourselves as an immorality, as a means of escape from all possible rules. We inherit the tradition of Christian morality which makes self-renunciation the condition for salvation. To know oneself was, paradoxically, a means of self-renunciation.

## Further resources

- Richard Shusterman. 2000. “Somaesthetics and Care of the Self: The Case of Foucault.” Monist 83(4): 530–551.

- Ahmed, Sara. [Selfcare as Warfare](https://feministkilljoys.com/2014/08/25/selfcare-as-warfare/), feministkilljoys blog, published on 25 August 2014 

- Michaeli, I. (2017). Self-Care: An Act of Political Warfare or a Neoliberal Trap? Development, 60(1-2), 50–56. 

- Keely Tongate, [“Women’s survival strategies in Chechnya: from self-care to caring for each other.”](https://www.opendemocracy.net/en/transformation/womens-survival-strategies-in-chechnya-from-self-care-to-caring-for-ea/) openDemocracy, 29 August 2013.


-  AWID Forum’s Wellbeing Advisory Group and the Black Feminisms Forum. [Webinar Summary: Self-Care and Collective Wellbeing.](https://www.awid.org/news-and-analysis/webinar-summary-self-care-and-collective-wellbeing)    


# Caring as a Way of Knowing


## Some key readings

- ![](bib:f84d5ef7-bc1a-4ac4-b155-74974c9bbc0a), in Haraway, D. (ed.), Simians, Cyborgs, and Women: The Reinvention of Nature, 183–201, New York: Routledge. 

- ![](bib:1643ef2b-c9d8-4eb1-baf5-730144eadc6d)

- Isabelle Stengers. [The Care of the Possible: Isabelle Stengers Interviewed by Erik Bordeleau](https://library.memoryoftheworld.org/#/book/e65d708d-336d-45e0-bab1-73b6b89d8859).



## Further resources

- Sandra Harding. [The Science Question in Feminism](https://library.memoryoftheworld.org/#/book/6e8e06be-8bb4-4546-9092-787312e83b01), Ithaca, NY: Cornell University Press, 1986.

- ![](bib:c857d80d-a987-443e-855e-4c4a16ef05c0)

- ![](bib:c51c4670-02a7-42e0-b29d-7b5febcf417f)
- 
- ![](bib:220246b3-5f92-4cf0-aba2-ea2ede7a65c8)

- Isabelle Stengers. [Another Science Is Possible: A Manifesto for Slow Science.](https://library.memoryoftheworld.org/#/book/01bb6f33-8d9d-4318-833c-ca2d925793b9) Polity, 2018. 
- ![](bib:62710c35-a605-4a3c-ac04-64cd74d1b1ac)



# Care Labour and Social Reproduction


## Some introductory readings

- ![](bib:88742e58-92de-457f-ac08-099db3b4bbc7)

- Rada Katsarova. [“Repression and Resistance on the Terrain of Social Reproduction: Historical Trajectories, Contemporary Openings.”](https://www.viewpointmag.com/2015/10/31/repression-and-resistance-on-the-terrain-of-social-reproduction-historical-trajectories-contemporary-openings/) Viewpoint magazine. October 31, 2015.


- Celeste Murillo. [“Producing and Reproducing: Capitalism’s Dual Oppression of Women.”](https://www.leftvoice.org/On-Reproductive-Labor-Wage-Slavery-and-the-New-Working-Class) Left Voice. September 11, 2018.


- ![](bib:5b1e973f-cfb5-4ca7-a678-89495a315eff)

## Some key readings

- ![](bib:cd3b2994-fabc-4642-a1dd-4e18ba184b85)

- Arlie Russell Hochschild.  [The Managed Heart: Commercialization of Human Feeling.](https://library.memoryoftheworld.org/#/book/07d2b96c-3703-4752-9e65-30b7f44e4691)
University of California Press, 2012.


- Leopoldina Fortunati. [The Arcane of Reproduction: Housework, Prostitution, Labor and Capital.](https://library.memoryoftheworld.org/#/book/4467b300-ea2c-4ca7-9f50-d77033c0b276)
Autonomedia, 1995.


- Silvia Federici. [Wages Against Housework.](https://library.memoryoftheworld.org/#/book/0860b3b2-7fb7-4038-9373-42765366c13e) Bristol: Power of Women Collective and the Falliing Wall Press. 1975


- Silvia Federici. [Caliban and the Witch: women, the body and primitive accumulation.](https://library.memoryoftheworld.org/#/book/88f27dc9-a2c4-4445-beac-5f423c458a1d) Autonomedia, 2004. 


- ![](bib:e57fa2af-d801-40b7-a112-d06af86eacd6)


- ![](bib:f1711c2d-0032-45fa-9b29-82d3f3ca3c92)



## Further resources

- Susan Ferguson at al. Historical Materialism Volume 24, Issue 2 (2016) Symposium on Social Reproduction.

- Katie Meehan and Kendra Strauss (Editors), [Precarious Worlds: Contested Geographies of Social Reproduction](https://library.memoryoftheworld.org/#/book/58a7f3d2-4fdd-4b8f-8d10-4495999c6fa7). Athens and London: The University of Georgia Press. 2015.


- ![](bib:11860f86-fd66-4cae-a8ec-3ea35e83e6c4)

- Lise Vogel, “Domestic Labor Revisited”. Science & Society, Volume 64, Number 2 (Summer, 2000), pp. 151-170 

- Annemarie Mol, The Logic of Care: Health and the Problem of Patient Choice, Routledge, 2008

- Carolyn Merchant, [Radical Ecology: The Search for a Livable World.](https://library.memoryoftheworld.org/#/book/63c547bc-13d6-4da1-b78b-9747a65d7295) Routledge, 2012. 

- Raj Patel and Jason W Moore: A History of the World in Seven Cheap Things: A Guide to Capitalism, Nature, and the Future of the Planet. University of California Press, Year: 2017

- Louis Althusser. [On the Reproduction of Capitalism: Ideology and Ideological State Apparatuses.](https://library.memoryoftheworld.org/#/book/2cb4578e-4df0-423a-b913-504cb8f31346) Verso, 2014. 

- Michelle Murphy. [Seizing the Means of Reproduction: Entanglements of Feminism, Health, and Technoscience.](https://library.memoryoftheworld.org/#/book/4d9f8f68-f9d6-46cf-99a8-bd48ef6f4b16)  Duke University, 2012/

- [Caring Labour: an archive](https://caringlabor.wordpress.com/). Website.
This site was born as an attempt by students in the East Bay in California to understand our role in the fight to prevent the closure of a community college childcare center and the layoffs of eight childcare workers. 


- [CareForce](http://www.careforce.co/) (film / public art project)

Initiated by artist [Marisa Morán Jahn](https://www.marisajahn.com/careforce) (Studio REV-) with the National Domestic Workers Alliance (NDWA), the CareForce is an ongoing set of public art projects amplifying the voices of America’s fastest growing workforce — caregivers. 


- Mierle Laderman Ukeles. [Manifesto for Maintenance Art. Proposal For An Exhibition “Care”](https://www.queensmuseum.org/wp-content/uploads/2016/04/Ukeles_MANIFESTO.pdf). 1969.


- [The Reproductive Sociology Research Group](http://www.reprosoc.com/), Cambridge University.


- ![](bib:2b36abff-6716-47ab-92d7-164aed40df8d)

- bell hooks. [“Homeplace (A Site of Resistance)”.](http://libcom.org/files/hooks-reading-1.pdf) In: Yearning: Race, gender, and cultural politics. Boston, MA: South End Press. Chicago, 1990. 

- Susan Stall and Randy Stoecker. “Community Organizing or Organizing Community? Gender and the Crafts of Empowerment”. Gender and Society, Vol. 12, No. 6, Special Issue: Gender and Social Movements, Part 1
(Dec., 1998), pp. 729-756.