---
title: Fostering equity and diversity in the hacker/maker scene
has_sessions: diversifingyournarratives, mappingtheunspoken, etextilesasatooltodecolonizeelectronics
---


# Introduction
Pirate Care is an emergent phenomenon where a growing number of initiatives related to health and care find themselves inhabiting grey regulatory zones, which pop-up more and more often. At the same time, a lot of projects born within the maker community, intersecting with hacker culture, are using open source and digital technologies to co-create solutions in situations where public or private institutions are idle. 

These initiatives share the vision that technology can be redirected toward new purposes and grounded to sustain different narratives, in which citizen perceive themselves as “contributors” rather than “consumers” of technology and science. Actively countering the deterministic trends of both these domains, the makers’ approach enhances the relation with the world through concrete material engagement, by challenging normative views of knowledge production and expertise.

Hackers and Makers ideally embrace an egalitarian vision of making, but very often, in practice, we see that at the level of access and opportunities such values lack a concrete application, because making always takes place in spaces and times influenced by institutional, societal, and individual histories.

This contribution to the Pirate Care Syllabus is a tentative effort to start a process of sharing resources and practices to recognise, on one side, how science and technology have been playing a leading role in the toolbox of the powerful, by limiting the self-empowerment of historically marginalized communities and/or reinforcing existing values and biased ideologies. On the other side, this tpoic hopes to spread a set of resources and tools within the maker community, to help it avoid the same mistakes other disciplines have done in the past and to bring awareness on the different opportunities unfolding with a more diverse approach.  

From an activist perspective, the word “decolonising” is becoming more and more useful for naming and understanding broader implications of phenomena that have a long history in shaping the social, much beyond physical borders. As [Beatrice Martini](https://beatricemartini.it/blog/decolonizing-technology-reading-list/) highlights in the introduction of her reading list:

> ”One example of this kind of ‘borderless colonial’ phenomenon comes from digital technology. While many technical innovations are asserted as universally positive and beneficial to communities worldwide, beyond borders and across cultures, a closer analysis of who holds the power, who has agency, and whose interests are promoted, can often reveal a very different picture.” <

Therefore we need to pay deeper attention to what constitutes a "community" and how the unequal distribution of agency impacts the way learning and making can take shape across the borders of gender, race, and class.

In recent years, the science and tech community has been taking a self-reflexive look at the role these fields of expertise played historically and presently in society, to prevent perpetuating mistakes and address patterns of exclusion. In the same way, this syllabus topic is an invitation for the maker/hacker community to embed this perspective in our practices because even science, which is first of all a method, but soon became an industry and a dispositive of power, has proved to be harmful, if not guided by ethical principles of equity.  

As makers and hackers, developing a perspective look at our places and practices means being aware that people can simultaneously experience privilege and oppression depending on the context. The image below shows the framework by the **Intersectionality** concept which was coined by lawyer and civil rights advocate Kimberlé W. Crenshaw in 1989, and rooted in the research and activism of women of color, extending back to Sojourner Truth’s [“Ain’t I a Woman”](https://www.nps.gov/articles/sojourner-truth.htm) speech in 1851. It reveals how the most pressing social justice issues can't be productively addressed through traditional frameworks or by explaining these problems as the product of just one axis of exclusion. We need to take a deeper look at the interconnected factors that influence power, privilege and oppression and the intersectional approach helps focus on systems and contexts to be decolonised. 

In the makerspaces, hacking and fablab context, this means considering who is impacted (or not) by the work that we do, whose voices are missing, questioning assumptions made in activities, while we engage the community or design our educational programs.

Below, you will find a series of publications, links and media to explore different points of view addressing the issue.

This topic has (so far) three sessions, where I proposed 3 possible activities to inspire action:

- ![](session:diversifingyournarratives)
- ![](session:mappingtheunspoken)
- ![](session:etextilesasatooltodecolonizeelectronics)


![Intersectionality Spectrum](https://www.awis.org/wp-content/uploads/intersectionality-sources-cited.jpg)

# Reading Resources

## Books


- ![](bib:bc873b84-96a0-440a-9705-b3f10baf5953)
- ![](bib:2246f4cb-4a25-4e26-8c42-f3e5b48ad86c)
- ![](bib:60d36344-adb2-4238-a886-d1c02dafc19a)
- ![](bib:c857d80d-a987-443e-855e-4c4a16ef05c0)
- ![](bib:7fd5acf6-c53d-42b8-9a60-31d94cd1b11b)
- ![](bib:54a1bc0e-5fd2-4ca1-90d3-ec9ba5e84195)
- ![](bib:c1de9fee-5428-4195-8b2b-6fe7dbd8c8e6)
- ![](bib:db3d2cf0-7eaf-46fb-9532-4a9daf1c6535)

---

## Papers
- ![](bib:f84d5ef7-bc1a-4ac4-b155-74974c9bbc0a)
- ![](bib:c55ccb47-8557-4014-8149-fb80abb40156)
- ![](bib:0d461bed-1bb2-443a-a263-e94843895ddb)  
- ![](bib:1c236cac-9b7e-4e50-9353-b433a93ed82e) 
- [Feminist and women's hackerspaces](https://geekfeminism.wikia.org/wiki/Feminist_and_women%27s_hackerspaces) 

- ![](bib:34d5fc09-931c-4a50-9bd3-8d442b4291fb) 
- ![](bib:17a78340-e9a4-4080-af5d-d59693a296da)
- ![](bib:89fa1e3c-0013-4e01-a7b4-5bce3e30c1fe)
- ![](bib:17619836-5cbd-4c55-a7a9-b5d94fd5099b) 
- [How Race & Gender Interact To Shape Inequality](https://decolonizeallthethings.com/2019/03/19/how-race-gender-interact-to-shape-inequality/) 
- [A Longitudinal Study of Equity-Oriented STEM-Rich Making Among Youth From Historically Marginalized Communities ](https://journals.sagepub.com/doi/10.3102/0002831218758668)
- ![](bib:1c236cac-9b7e-4e50-9353-b433a93ed82e)
- [Queer Science: LGBT Scientists Discuss Coming Out at Work](https://www.bitchmedia.org/post/queer-science-lgbt-scientists-discuss-coming-out-at-work)
- ![](bib:38e08cc6-b47a-4cc5-b170-1173afd76cac)
- ![](bib:47c73092-1ba0-4b92-ae00-20eb45871996) 
- ![](bib:ab904333-d9fb-42e2-8754-89dcee55adde)
---

## Articles

- ![](bib:5f97d0cf-3bf1-43b9-8a0c-32da74ffe717)

On decolonizing as a concept
- [We need a decolonized not a diverse education](http://harlot.media/articles/1058/we-need-a-decolonized-not-a-diverse-education)
- [Digital Colonialism, the internet as a tool of cultural hegemony](https://web.archive.org/web/20190316002911/http://www.knowledgecommons.in/brasil/en/whats-wrong-with-current-internet-governance/digital-colonialism-the-internet-as-a-tool-of-cultural-hegemony/) 
- ![](bib:2020bc10-ff93-434f-8309-f59f2e829e27)


On gender diversity 

- ![What happened to Women in computer science?](https://hackernoon.com/hn-images/1*mVqtLT4yiwjgZovRSNvTkw.png)

- ![](bib:da17941f-c5a0-421e-82cf-8d1e4c050bc4)

- ![](bib:778532ad-f303-489f-b201-98a80209f7b5) 

- ![](bib:5b633d01-e68d-4cab-93d5-91981b7ad83a)

- ![](bib:247801a3-ea43-4dc6-bb10-5f47f60994af)

On horizontality

- ![](bib:8890b894-9bac-4095-af69-da24929cb2f0)

---

## Links

- [D.A.T.S. Scientific Ethics Statement & Reading Guide](https://decolonizeallthescience.com/) 
- [Technology Colonialism](https://modelviewculture.com/pieces/technology-colonialism ) 
- [Decolonisation is not a metaphor](https://www.researchgate.net/publication/277992187_Decolonization_Is_Not_a_Metaphor)
- [Timeline of geek feminism](https://geekfeminism.wikia.org/wiki/Timeline_of_geek_feminism) 
- [Timeline of women in computing ](https://rarlindseysmash.com/WiCVis/index.html) 
- [Computer Grrrls - Exhibition](https://gaite-lyrique.net/en/event/computer-grrrls)
- [Computer Grrrls - Leaflet](https://gaite-lyrique.net/storage/2019/04/04/computer-grrrls-exhibition-leaflet-english.pdf)
- [Google’s Ideological Echo Chamber](https://assets.documentcloud.org/documents/3914586/Googles-Ideological-Echo-Chamber.pdf)
- [Decolonizing Design](http://www.decolonisingdesign.com/statements/2016/editorial/)

---

## Podcasts

- [When Women stopped coding](https://www.npr.org/sections/money/2014/10/17/356944145/episode-576-when-women-stopped-coding")

---


## Videos
- [Inclusion & Exclusion collection on Hack_curio](https://hackcur.io/category/inclusions-exclusions/)

---

Wanna contribute? Drop me a message on twitter @zoescope